@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace DoctrineTest\InstantiatorPerformance;
 
 use ArrayObject;
@@ -17,8 +19,7 @@ use PhpBench\Benchmark\Metadata\Annotations\Revs;
  */
 class InstantiatorPerformanceBench
 {
-    /** @var Instantiator */
-    private $instantiator;
+    private Instantiator $instantiator;
 
     public function init(): void
     {
